# zoom-pan

zoom and pan implementation in vanillaJS

## Getting Started

To build minify files you have to install browserify and uglify-es

### Prerequisites

```
npm install -g browserify
```
```
npm install -g uglify-es
```

### Build

```
npm run build
```

### Installing

```
npm install
```

### Run

```
npm run server
```

## Running the tests

```
npm test
```

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

